@@ -15,11 +15,11 @@ use Config;
 use subs qw(quotemeta);
 
 #####################################
-$VERSION = '3.38';
+$VERSION = '3.41';
 #####################################
 # Globals ###########################
 $open = '\$R';
-#my @non_flow = qw(VAR SQL SET PSET PGET PIC STATE INDEX CFG);
+#my @non_flow = qw(VAR SQL ASSIGN SET PSET PGET PIC STATE INDEX CFG);
 #@non_flow{@non_flow} = @non_flow;
 
 my @printers = qw(VERSION VAR SQL GET PGET PVAR INDEX PIC STATE CFG INI LOGIN 
@@ -120,6 +120,41 @@ sub Translate
 	my $fetch = '(' . join(", ", @fetch) . ')';
 	($result, $fetch);
 }
+#################################
+# CGI parsing utility		#
+#################################
+sub ParseForm
+{
+        my $toParse = shift;
+        my ($name , $value , @pairs , $pair , %FORM);
+        @pairs = split(/&/, $toParse);
+        foreach $pair (@pairs) {
+                ($name, $value) = split(/=/, $pair);
+                $value =~ tr/+/ /;
+                $value =~ s/%([a-fA-F0-9][a-fA-F0-9])/pack("C", hex($1))/eg;
+                $FORM{$name} = $value;
+                #Debug("kak : $name \=  $value");
+        }
+        return \%FORM;
+}
+#####################################
+sub CgiParse
+{
+        my $GFORM =  &ParseForm($ENV{'QUERY_STRING'});
+        my $buffer;
+        read(STDIN, $buffer, $ENV{'CONTENT_LENGTH'});
+        my $PFORM = &ParseForm($buffer);
+
+        my (%FORM , $key);
+        foreach $key(keys %$GFORM){
+                $FORM{$key} = $GFORM->{$key};
+        }
+
+        foreach $key(keys %$PFORM){
+                $FORM{$key} = $PFORM->{$key};
+        }
+        return \%FORM;
+}
 #####################################
 sub WantTag 
 {
@@ -702,12 +737,16 @@ sub DoSQL
 
 	return "\$engines{\"$engine\"}->Var(\"$1\")";
 }
-######################################
-sub DoIF {
+#####################################
+sub DoIF 
+{
 	my ($self, $engine, $param) = @_;
-	unless ($param =~ s/^\\[\.=]\\(['"])(.*)\\\1$//s) {
+
+	unless ($param =~ s/^\\[\.=]\\(['"])(.*)\\\1$//s) 
+	{
 		$self->Syntax;
 	}
+
 	my $text = <<EOM;
 HTML::Merge::Error::HandleError('INFO', "$2", 'IF');
 my \$__test = eval("$2");
@@ -717,7 +756,31 @@ EOM
 	$self->Push('if', $engine);
 	$text;
 }
+#####################################
+sub DoTIF 
+{
+	my ($self, $engine, $param) = @_;
+	unless ($param =~ s/^\\[\.=]\\(['"])(.*)\\\1$//s) 
+	{
+		$self->Syntax;
+	}
 
+	my $text = <<EOM;
+HTML::Merge::Error::HandleError('INFO', "$2", 'IF');
+my \$__test = "$2";
+HTML::Merge::Error::HandleError('ERROR', \$@) if (\$@);
+if ("$2") {
+EOM
+	$self->Push('if', $engine);
+	$text;
+}
+#####################################
+sub DoUnTIF {
+	my ($self, $engine, $param) = @_;
+	$self->Expect($engine, 'if', 'else');
+	"}\n";
+}
+#####################################
 sub DoELSIF {
 	my ($self, $engine, $param) = @_;
 	unless ($param =~ s/^\\[\.=]\\(['"])(.*)\\\1$//s) {
@@ -796,8 +859,7 @@ sub DoEVAL {
         }
         "eval(\"$2\")";
 }
-
-
+#####################################
 sub DoPERL {
         my ($self, $engine, $param) = @_;
 	my $type;
@@ -857,14 +919,31 @@ EOM
 	}
 	$text;
 }
-
-sub DoSET {
+###############################################################
+sub DoSET 
+{
         my ($self, $engine, $param) = @_;
-	unless ($param =~ s/^\\\.(.+?)\\=\\(['"])(.*?)\\\2$//s) {
+
+	unless ($param =~ s/^\\\.(.+?)\\=\\(['"])(.*?)\\\2$//s) 
+	{
 		$self->Syntax;
 	}
-	"\$vars{\"$1\"} = eval(\"$3\");\n";
+
+	return "\$vars{\"$1\"} = eval(\"$3\");\n";
 }
+###############################################################
+sub DoASSIGN 
+{
+        my ($self, $engine, $param) = @_;
+
+	unless ($param =~ s/^\\\.(.+?)\\=\\(['"])(.*?)\\\2$//s) 
+	{
+		$self->Syntax;
+	}
+
+	return "\$vars{\"$1\"} = \"$3\";\n";
+}
+###############################################################
 
 sub DoPCLEAR {
         my ($self, $engine, $param) = @_;
@@ -1877,11 +1956,12 @@ sub safecreate {
                 mkdir $dir, 0755;
         }
 }
-
-
-sub CompileFile {
+#####################################
+sub CompileFile 
+{
 	my ($file, $out, $sub) = @_;
 
+	my $tmp;
 	open(I, $file) || die "Cannot open $file: $!";
 	my $text = join("", <I>);
 	close(I); 
@@ -1936,6 +2016,15 @@ sub CompileFile {
 	foreach (@keys) {
 		$vars{$_} = param($_);
 	}
+=line
+	$tmp = HTML::Merge::Compile::CgiParse();
+	foreach (keys(%$tmp))
+	{
+		print "$_\t:\t",$tmp->{$_},"\n";
+	}
+
+	%vars = %$tmp; 
+=cut
 	unless ($HTML::Merge::Ini::TEMPLATE_CACHE) {
 	
 EOM
