@@ -177,7 +177,6 @@ sub Preconnect
 sub DoConnect 
 {
 	my $self = shift;
-
 	return if $self->{'dbh'};
 
 	require DBI;
@@ -382,7 +381,7 @@ sub CreateSessionTable
 	my $ddl = "CREATE TABLE $table (
 			session_id VARCHAR(20) NOT NULL,
 			varname VARCHAR(30) NOT NULL,
-			vardata VARCHAR(30) NOT NULL
+			vardata VARCHAR(255) NOT NULL
 		   )";
 	# there is no relevance ro the value of the internal db because 
 	# the program only need to know if we use mysql
@@ -681,7 +680,6 @@ sub DBH
 sub SYS_DBH
 {
 	my $self = shift;
-
 	return $self->{'sys_dbh'} if $self->{'sys_dbh'} ;
 	return $self->DBH() if $HTML::Merge::Ini::SESSION_DB;
 
@@ -712,7 +710,8 @@ sub AddUser
 	croak "Can't change user $user"
 		if ($user eq $HTML::Merge::Ini::ROOT_USER);
 
-	my $table = "users_t";
+	my $db = ($HTML::Merge::Ini::SESSION_DB)?"$HTML::Merge::Ini::SESSION_DB.":'';
+	my $table = $db."users_t";
 
 	my $salt = pack("CC", rand(26) + 65 ,rand(26) + 65);
 	my $cp = crypt($password, $salt);
@@ -880,7 +879,8 @@ sub Require
 	my ($self, $template, $realms) = @_;
 	my @realms = split(/,\s*/, $realms);
 	my $tid = $self->GetTemplateID($template);
-	my $table = "realm_template_matrix";
+	my $db = ($HTML::Merge::Ini::SESSION_DB)?"$HTML::Merge::Ini::SESSION_DB.":'';
+	my $table = $db."realm_template_matrix";
 	my $iid = $self->GetInstance;
 	
 	my $dbh = $self->SYS_DBH();
@@ -896,15 +896,15 @@ sub Require
 sub InitDatabase 
 {	
 	my $self = shift;
-
 	$self ||= __PACKAGE__->CreateObject();
+	
+	my $sysdata_file = "$HTML::Merge::Ini::MERGE_ABSOLUTE_PATH/private/sql/tbl.dat"; 
 
 	$self->CreateMeta();
 	# now let's create the meta data tables_internal 
 	$self->CreateMetaDataTable();
-
 	# populate default meta
-	$self->LoadSysTableFromFile('tbl.dat');
+	$self->LoadSysTableFromFile($sysdata_file);
 	
 	foreach (@objects) 
 	{
@@ -1487,12 +1487,14 @@ sub Linkers
 	my ($self, $child, $parent) = @_;
 	my $sql;
 	my ($check, $read) = ($parent, $child);
+	my $db = ($HTML::Merge::Ini::SESSION_DB)?"$HTML::Merge::Ini::SESSION_DB.":'';
 	Order($child, $parent);
        	$sql = "SELECT DISTINCT B.${read}name
-               	FROM ${child}_${parent}_matrix A,
-                ${read}s_t B
+               	FROM ${db}${child}_${parent}_matrix A,
+                ${db}${read}s_t B
                	WHERE B.id = A.${read}_id
                 ORDER BY B.${read}name";
+
 	$self->LoadArray($sql);
 }
 ###############################################################################
@@ -1564,7 +1566,6 @@ sub CreateMetaDataTable
 	my $db = ($HTML::Merge::Ini::SESSION_DB)?"$HTML::Merge::Ini::SESSION_DB.":'';
 	my $table = "${db}tbl";
 	my $ddl = "CREATE TABLE $table (
-			rid INTEGER PRIMARY KEY,
 			tbl VARCHAR(6),
 			langug_code VARCHAR(6),
 			code VARCHAR(6),
@@ -1593,7 +1594,7 @@ sub LoadSysTableFromFile
 	my $dbh = $self->SYS_DBH();
 	my $db = ($HTML::Merge::Ini::SESSION_DB)?"$HTML::Merge::Ini::SESSION_DB.":'';
 	my (@col,$col,$val);
-	my $table;
+	my $table = $db;
 	my $sql;
 	my $sth;
 
@@ -1602,7 +1603,7 @@ sub LoadSysTableFromFile
 	open(I,"$file") || die "can't open data file $file";
 
 	# get first line
-	$table=<I>;
+	$table .= <I>;
 
 	chomp $table;
 
